# python-rtspm

[![PyPI version](https://img.shields.io/pypi/v/python-rtspm.svg)](https://pypi.python.org/pypi/python-rtspm)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/python-rtspm.svg)](https://pypi.org/project/python-rtspm/#files)
[![Build and Publish](https://github.com/OpenNFT/python-rtspm/workflows/Build%20and%20Publish/badge.svg)](https://github.com/OpenNFT/python-rtspm/actions/workflows/build-publish.yaml)
[![License](https://img.shields.io/pypi/l/python-rtspm.svg)](https://choosealicense.com/licenses/gpl-3.0)

Python adaptation of SPM functions for real-time fMRI analysis

## Installing

Python 3.6 or above is supported.

```
pip install python-rtspm
```
